@@ -88,7 +88,7 @@ class APGraph(OrderedDict):
             :graph_type (str): Graph type.
             :radio_type (str): Radio type.
             :start (int, optional): Graph start time(seconds ago).
-                Default is None.
+                Default is -7200.
             :end (int, optional): Graph end time(seconds ago).
                 Default is None.
 
@@ -115,7 +115,7 @@ class APGraph(OrderedDict):
         Args:
 
             :start (int, optional): Graph start time(seconds ago).
-                Default is None.
+                Default is -7200.
             :end (int, optional): Graph end time(seconds ago).
                 Default is None.
 
@@ -138,7 +138,7 @@ class APGraph(OrderedDict):
         Args:
 
             :start (int, optional): Graph start time(seconds ago).
-                Default is None.
+                Default is -7200.
             :end (int, optional): Graph end time(seconds ago).
                 Default is None.
 
@@ -155,13 +155,36 @@ class APGraph(OrderedDict):
         """
         return self.__ap_graph(u'ap_client_count', u'aN', start, end)
 
+    def client_count_802dot11ac(self, start=None, end=None):
+        """RRD graph URL for access point client count of radio type IEEE802.11AC.
+
+        Args:
+
+            :start (int, optional): Graph start time(seconds ago).
+                Default is -7200.
+            :end (int, optional): Graph end time(seconds ago).
+                Default is None.
+
+        Returns:
+
+            :str: Graph URL string.
+
+        Usage: ::
+
+            >>> ap_graph.client_count_802dot11ac(start=-3600)
+            'https://x.x.x.x/nf/rrd_graph?
+                end=-0s&id=1&radio_index=2&start=-3600s&type=ap_client_count'
+
+        """
+        return self.__ap_graph(u'ap_client_count', u'ac', start, end)
+
     def bandwidth_802dot11bgn(self, start=None, end=None):
         """RRD graph URL for access point bandwidth of radio type IEEE802.11BGN.
 
         Args:
 
             :start (int, optional): Graph start time(seconds ago).
-                Default is None.
+                Default is -7200.
             :end (int, optional): Graph end time(seconds ago).
                 Default is None.
 
@@ -184,7 +207,7 @@ class APGraph(OrderedDict):
         Args:
 
             :start (int, optional): Graph start time(seconds ago).
-                Default is None.
+                Default is -7200.
             :end (int, optional): Graph end time(seconds ago).
                 Default is None.
 
@@ -201,13 +224,36 @@ class APGraph(OrderedDict):
         """
         return self.__ap_graph(u'ap_bandwidth', u'aN', start, end)
 
+    def bandwidth_802dot11ac(self, start=None, end=None):
+        """RRD graph URL for access point bandwidth of radio type IEEE802.11AC.
+
+        Args:
+
+            :start (int, optional): Graph start time(seconds ago).
+                Default is -7200.
+            :end (int, optional): Graph end time(seconds ago).
+                Default is None.
+
+        Returns:
+
+            :str: Graph URL string.
+
+        Usage: ::
+
+            >>> ap_graph.bandwidth_802dot11ac(start=-3600)
+            'https://x.x.x.x/nf/rrd_graph?
+                end=-0s&id=3&radio_index=2&start=-3600s&type=ap_bandwidth'
+
+        """
+        return self.__ap_graph(u'ap_bandwidth', u'ac', start, end)
+
     def dot11_counters_802dot11bgn(self, start=None, end=None):
         """RRD graph URL for access point dot11 counters of radio type IEEE802.11BGN.
 
         Args:
 
             :start (int, optional): Graph start time(seconds ago).
-                Default is None.
+                Default is -7200.
             :end (int, optional): Graph end time(seconds ago).
                 Default is None.
 
@@ -230,7 +276,7 @@ class APGraph(OrderedDict):
         Args:
 
             :start (int, optional): Graph start time(seconds ago).
-                Default is None.
+                Default is -7200.
             :end (int, optional): Graph end time(seconds ago).
                 Default is None.
 
@@ -247,6 +293,29 @@ class APGraph(OrderedDict):
         """
         return self.__ap_graph(u'dot11_counters', u'aN', start, end)
 
+    def dot11_counters_802dot11ac(self, start=None, end=None):
+        """RRD graph URL for access point dot11 counters of radio type IEEE802.11AC.
+
+        Args:
+
+            :start (int, optional): Graph start time(seconds ago).
+                Default is -7200.
+            :end (int, optional): Graph end time(seconds ago).
+                Default is None.
+
+        Returns:
+
+            :str: Graph URL string.
+
+        Usage: ::
+
+            >>> ap_graph.dot11_counters_802dot11ac(start=-3600)
+            'https://x.x.x.x/nf/rrd_graph?
+                end=-0s&id=3&radio_index=2&start=-3600s&type=dot11_counters'
+
+        """
+        return self.__ap_graph(u'dot11_counters', u'ac', start, end)
+
     def __radio_graph(self, graph_type, radio_type, start, end):
         """RRD access point graph base method.
 
@@ -255,7 +324,7 @@ class APGraph(OrderedDict):
             :graph_type (str): Graph type.
             :radio_type (str): Radio type.
             :start (int, optional): Graph start time(seconds ago).
-                Default is None.
+                Default is -7200.
             :end (int, optional): Graph end time(seconds ago).
                 Default is None.
 
@@ -283,7 +352,7 @@ class APGraph(OrderedDict):
         Args:
 
             :start (int, optional): Graph start time(seconds ago).
-                Default is None.
+                Default is -7200.
             :end (int, optional): Graph end time(seconds ago).
                 Default is None.
 
@@ -307,7 +376,7 @@ class APGraph(OrderedDict):
         Args:
 
             :start (int, optional): Graph start time(seconds ago).
-                Default is None.
+                Default is -7200.
             :end (int, optional): Graph end time(seconds ago).
                 Default is None.
 
@@ -325,13 +394,37 @@ class APGraph(OrderedDict):
         """
         return self.__radio_graph(u'radio_channel', u'aN', start, end)
 
+    def radio_channel_802dot11ac(self, start=None, end=None):
+        """RRD graph URL for radio channel for radio type IEEE802.11AC.
+
+        Args:
+
+            :start (int, optional): Graph start time(seconds ago).
+                Default is -7200.
+            :end (int, optional): Graph end time(seconds ago).
+                Default is None.
+
+        Returns:
+
+            :str: Graph URL string.
+
+        Usage: ::
+
+            >>> ap_graph.radio_channel_802dot11ac(start=-3600)
+            'https://x.x.x.x/nf/rrd_graph?
+                ap_uid=00%3A00%3A10%3A00%3A00%3A03&
+                end=-0s&radio_index=2&radio_interface=1&start=-3600s&type=radio_channel'
+
+        """
+        return self.__radio_graph(u'radio_channel', u'ac', start, end)
+
     def radio_noise_802dot11bgn(self, start=None, end=None):
         """RRD graph URL for radio noise for radio type IEEE802.11BGN.
 
         Args:
 
             :start (int, optional): Graph start time(seconds ago).
-                Default is None.
+                Default is -7200.
             :end (int, optional): Graph end time(seconds ago).
                 Default is None.
 
@@ -355,7 +448,7 @@ class APGraph(OrderedDict):
         Args:
 
             :start (int, optional): Graph start time(seconds ago).
-                Default is None.
+                Default is -7200.
             :end (int, optional): Graph end time(seconds ago).
                 Default is None.
 
@@ -373,13 +466,37 @@ class APGraph(OrderedDict):
         """
         return self.__radio_graph(u'radio_noise', u'aN', start, end)
 
+    def radio_noise_802dot11ac(self, start=None, end=None):
+        """RRD graph URL for radio noise for radio type IEEE802.11AC.
+
+        Args:
+
+            :start (int, optional): Graph start time(seconds ago).
+                Default is -7200.
+            :end (int, optional): Graph end time(seconds ago).
+                Default is None.
+
+        Returns:
+
+            :str: Graph URL string.
+
+        Usage: ::
+
+            >>> ap_graph.radio_noise_802dot11ac(start=-3600)
+            'https://x.x.x.x/nf/rrd_graph?
+                ap_uid=00%3A00%3A10%3A00%3A00%3A03&
+                end=-0s&radio_index=2&radio_interface=1&start=-3600s&type=radio_noise'
+
+        """
+        return self.__radio_graph(u'radio_noise', u'ac', start, end)
+
     def radio_power_802dot11bgn(self, start=None, end=None):
         """RRD graph URL for radio power for radio type IEEE802.11BGN.
 
         Args:
 
             :start (int, optional): Graph start time(seconds ago).
-                Default is None.
+                Default is -7200.
             :end (int, optional): Graph end time(seconds ago).
                 Default is None.
 
@@ -403,7 +520,7 @@ class APGraph(OrderedDict):
         Args:
 
             :start (int, optional): Graph start time(seconds ago).
-                Default is None.
+                Default is -7200.
             :end (int, optional): Graph end time(seconds ago).
                 Default is None.
 
@@ -421,13 +538,37 @@ class APGraph(OrderedDict):
         """
         return self.__radio_graph(u'radio_power', u'aN', start, end)
 
+    def radio_power_802dot11ac(self, start=None, end=None):
+        """RRD graph URL for radio power for radio type IEEE802.11AC.
+
+        Args:
+
+            :start (int, optional): Graph start time(seconds ago).
+                Default is -7200.
+            :end (int, optional): Graph end time(seconds ago).
+                Default is None.
+
+        Returns:
+
+            :str: Graph URL string.
+
+        Usage: ::
+
+            >>> ap_graph.radio_power_802dot11ac(start=-3600)
+            'https://x.x.x.x/nf/rrd_graph?
+                ap_uid=00%3A00%3A10%3A00%3A00%3A03&
+                end=-0s&radio_index=2&radio_interface=2&start=-3600s&type=radio_power'
+
+        """
+        return self.__radio_graph(u'radio_power', u'ac', start, end)
+
     def radio_errors_802dot11bgn(self, start=None, end=None):
         """RRD graph URL for radio errors for radio type IEEE802.11BGN.
 
         Args:
 
             :start (int, optional): Graph start time(seconds ago).
-                Default is None.
+                Default is -7200.
             :end (int, optional): Graph end time(seconds ago).
                 Default is None.
 
@@ -451,7 +592,7 @@ class APGraph(OrderedDict):
         Args:
 
             :start (int, optional): Graph start time(seconds ago).
-                Default is None.
+                Default is -7200.
             :end (int, optional): Graph end time(seconds ago).
                 Default is None.
 
@@ -469,13 +610,37 @@ class APGraph(OrderedDict):
         """
         return self.__radio_graph(u'radio_errors', u'aN', start, end)
 
+    def radio_errors_802dot11ac(self, start=None, end=None):
+        """RRD graph URL for radio errors for radio type IEEE802.11AC.
+
+        Args:
+
+            :start (int, optional): Graph start time(seconds ago).
+                Default is -7200.
+            :end (int, optional): Graph end time(seconds ago).
+                Default is None.
+
+        Returns:
+
+            :str: Graph URL string.
+
+        Usage: ::
+
+            >>> ap_graph.radio_errors_802dot11ac(start=-3600)
+            'https://x.x.x.x/nf/rrd_graph?
+                ap_uid=00%3A00%3A10%3A00%3A00%3A03&
+                end=-0s&radio_index=2&radio_interface=2&start=-3600s&type=radio_errors'
+
+        """
+        return self.__radio_graph(u'radio_errors', u'ac', start, end)
+
     def radio_goodput_802dot11bgn(self, start=None, end=None):
         """RRD graph URL for radio goodput for radio type IEEE802.11BGN.
 
         Args:
 
             :start (int, optional): Graph start time(seconds ago).
-                Default is None.
+                Default is -7200.
             :end (int, optional): Graph end time(seconds ago).
                 Default is None.
 
@@ -499,7 +664,7 @@ class APGraph(OrderedDict):
         Args:
 
             :start (int, optional): Graph start time(seconds ago).
-                Default is None.
+                Default is -7200.
             :end (int, optional): Graph end time(seconds ago).
                 Default is None.
 
@@ -517,13 +682,37 @@ class APGraph(OrderedDict):
         """
         return self.__radio_graph(u'radio_goodput', u'aN', start, end)
 
+    def radio_goodput_802dot11ac(self, start=None, end=None):
+        """RRD graph URL for radio goodput for radio type IEEE802.11AC.
+
+        Args:
+
+            :start (int, optional): Graph start time(seconds ago).
+                Default is -7200.
+            :end (int, optional): Graph end time(seconds ago).
+                Default is None.
+
+        Returns:
+
+            :str: Graph URL string.
+
+        Usage: ::
+
+            >>> ap_graph.radio_goodput_802dot11ac(start=-3600)
+            'https://x.x.x.x/nf/rrd_graph?
+                ap_uid=00%3A00%3A10%3A00%3A00%3A03&
+                end=-0s&radio_index=2&radio_interface=2&start=-3600s&type=radio_goodput'
+
+        """
+        return self.__radio_graph(u'radio_goodput', u'ac', start, end)
+
     def channel_utilization_802dot11bgn(self, start=None, end=None):
         """RRD graph URL for channel utilization for radio type IEEE802.11BGN.
 
         Args:
 
             :start (int, optional): Graph start time(seconds ago).
-                Default is None.
+                Default is -7200.
             :end (int, optional): Graph end time(seconds ago).
                 Default is None.
 
@@ -547,7 +736,7 @@ class APGraph(OrderedDict):
         Args:
 
             :start (int, optional): Graph start time(seconds ago).
-                Default is None.
+                Default is -7200.
             :end (int, optional): Graph end time(seconds ago).
                 Default is None.
 
@@ -565,6 +754,30 @@ class APGraph(OrderedDict):
         """
         return self.__radio_graph(u'channel_utilization', u'aN', start, end)
 
+    def channel_utilization_802dot11ac(self, start=None, end=None):
+        """RRD graph URL for channel utilization for radio type IEEE802.11AC.
+
+        Args:
+
+            :start (int, optional): Graph start time(seconds ago).
+                Default is -7200.
+            :end (int, optional): Graph end time(seconds ago).
+                Default is None.
+
+        Returns:
+
+            :str: Graph URL string.
+
+        Usage: ::
+
+            >>> ap_graph.channel_utilization_802dot11ac(start=-3600)
+            'https://x.x.x.x/nf/rrd_graph?
+                ap_uid=00%3A00%3A10%3A00%3A00%3A03&
+                end=-0s&radio_index=2&radio_interface=2&start=-3600s&type=channel_utilization'
+
+        """
+        return self.__radio_graph(u'channel_utilization', u'ac', start, end)
+
     @staticmethod
     def urlencode(params):
         """URL Encode."""
